---
title: <span class="badge object-type-scalar"></span> IndonesianRupiah
---
# <span class="badge object-type-scalar"></span> IndonesianRupiah

Currency: Indonesian Rupiah (Rp)

## Definition

```python
# Currency: Indonesian Rupiah (Rp)
IndonesianRupiah: typing.Literal["currencyIDR"] = "currencyIDR"
```
